==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebFilteringExpressionsTreeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDetailDescriptionMetadata } from "./WebFilteringExpressionsTreeDetailDescriptionMetadata";
import { WebFilteringExpressionsTreeEventArgsDescription } from "./WebFilteringExpressionsTreeEventArgsDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeEventArgsDescriptionMetadata.c(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
            WebFilteringExpressionsTreeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebFilteringExpressionsTreeDetail");
        }
        static d(a) {
            WebFilteringExpressionsTreeEventArgsDescriptionMetadata.b(a);
            a.ad("WebFilteringExpressionsTreeEventArgs", () => new WebFilteringExpressionsTreeEventArgsDescription());
            a.ac("WebFilteringExpressionsTreeEventArgs", WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeEventArgsDescriptionMetadata, 'WebFilteringExpressionsTreeEventArgsDescriptionMetadata');
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebFilteringExpressionsTreeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDetailDescriptionMetadata } from "./WebFilteringExpressionsTreeDetailDescriptionMetadata";
import { WebFilteringExpressionsTreeEventArgsDescription } from "./WebFilteringExpressionsTreeEventArgsDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeEventArgsDescriptionMetadata.c(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
            WebFilteringExpressionsTreeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebFilteringExpressionsTreeDetail");
        }
        static d(a) {
            WebFilteringExpressionsTreeEventArgsDescriptionMetadata.b(a);
            a.ae("WebFilteringExpressionsTreeEventArgs", () => new WebFilteringExpressionsTreeEventArgsDescription());
            a.ad("WebFilteringExpressionsTreeEventArgs", WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeEventArgsDescriptionMetadata, 'WebFilteringExpressionsTreeEventArgsDescriptionMetadata');
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeEventArgsDescriptionMetadata;
})();
